@@ -22,14 +22,13 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-from .seeder import ClassRegistry
 from .seeder import HybridSeeder
 from .seeder import Seeder
 from .loader import load_entities_from_json
 from .loader import load_entities_from_yaml
+from .loader import load_entities_from_csv
 
-__version__ = '0.4.3'
-
+__version__ = '1.0.0'
 
 if __name__ == '__main__':
     pass
